GenericCalcPercentageLeaf

Struct GenericCalcPercentageLeaf 

#[repr(C)]
pub struct GenericCalcPercentageLeaf<P> { pub value: P, pub hint: Optional<NumericBaseType>, }
The value of a percentage leaf node that contains an associated percent hint.

Fields

value: P

The percentage value.

hint: Optional<NumericBaseType>

The base type the percentage resolves against, or None if there is no specific percent hint (this is used by CSS Typed OM when parsing an expression without the context of a property).

Implementations

Source

impl<P> GenericCalcPercentageLeaf<P>
where P: From<f32> + Copy, f32: From<P>,

pub fn new(value: f32, hint: Optional<NumericBaseType>) -> Self

Builds a percentage leaf with the given percent hint.

pub fn get(&self) -> f32

Returns the percentage value as a float.

pub fn numeric_type(&self) -> NumericType

Returns the numeric type of this percentage.

pub fn combined_hint(&self, other: &Self) -> Optional<NumericBaseType>

Returns the percent hint to use when merging two percentages with an arithmetic operation. Mismatched hints should be impossible after type checking.