#[repr(C)]pub struct GenericRandomFunction<L> {
pub key: GenericCalcNode<L>,
pub min: GenericCalcNode<L>,
pub max: GenericCalcNode<L>,
pub step: Optional<GenericCalcNode<L>>,
}Expand description
A random() function.
https://drafts.csswg.org/css-values-5/#funcdef-random
Fields
key: GenericCalcNode<L>The <random-key>, resolving to the random base value.
min: GenericCalcNode<L>The minimum value the function can resolve to, inclusive.
max: GenericCalcNode<L>The maximum value the function can resolve to, inclusive.
step: Optional<GenericCalcNode<L>>The optional step value.