#[repr(C)]pub struct GenericCalcPercentageLeaf<P> {
pub value: P,
pub hint: Optional<NumericBaseType>,
}Expand description
The value of a percentage leaf node that contains an associated percent hint.
Fields
value: PThe percentage value.
hint: Optional<NumericBaseType>The base type the percentage resolves against, or None if there is no specific percent hint (this is used by CSS Typed OM when parsing an expression without the context of a property).
Implementations
Sourceimpl<P> GenericCalcPercentageLeaf<P>
impl<P> GenericCalcPercentageLeaf<P>
Sourcepub fn new(value: f32, hint: Optional<NumericBaseType>) -> Self
pub fn new(value: f32, hint: Optional<NumericBaseType>) -> Self
Builds a percentage leaf with the given percent hint.
Sourcepub fn numeric_type(&self) -> NumericType
pub fn numeric_type(&self) -> NumericType
Returns the numeric type of this percentage.
Sourcepub fn combined_hint(&self, other: &Self) -> Optional<NumericBaseType>
pub fn combined_hint(&self, other: &Self) -> Optional<NumericBaseType>
Returns the percent hint to use when merging two percentages with an arithmetic operation. Mismatched hints should be impossible after type checking.